# -*- coding: utf-8 -*-

from django.conf import settings
from articles.models import Category, Entry
from django.contrib import admin
from django.core.urlresolvers import reverse

class CategoryAdmin(admin.ModelAdmin):
    prepopulated_fields = { 'slug': ('title', )}
    list_display = ('id', 'title', 'slug', 'parent', 'order')
    list_display_links = ('id', )
    list_editable = ('title', 'slug', 'parent', 'order')


class EntryAdmin(admin.ModelAdmin):
    prepopulated_fields = { 'slug': ('title', )}
    search_fields = ['title', 'excerpt', 'body']
    list_filter = ('category', 'in_list', 'is_active')
    list_display = ('title', 'order')

    def formfield_for_dbfield(self, db_field, **kwargs):
        return super(EntryAdmin, self).formfield_for_dbfield(db_field, **kwargs)


admin.site.register(Category, CategoryAdmin)
admin.site.register(Entry, EntryAdmin)
